****************
Google Analytics
****************

Google Analytics or GA is used to know what it’s going on on a page without damage privacy.
GA is *NOT* used on Chat Page.

GA collects events:

* Clicking on "create chat" button
* Clicking on "join" button
* General visiting statistics for all pages except Chat
